@@ -5,7 +5,7 @@
 ##   Logtalk script for updating the HTML core, library, tools, and
 ##   contributions documentation
 ## 
-##   Last updated on May 16, 2018
+##   Last updated on October 8, 2018
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
 ##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
@@ -39,7 +39,7 @@ fi
 
 
 # default to SWI-Prolog as some of the documentation should be
-# generated using a multi-threaded back-end Prolog compiler
+# generated using a multi-threaded backend Prolog compiler
 backend=swipl
 prolog='SWI-Prolog'
 logtalk="swilgt$extension -g"
@@ -47,7 +47,7 @@ logtalk="swilgt$extension -g"
 cwd=$(pwd)
 
 # documentation goal
-goal="set_logtalk_flag(source_data,on),logtalk_load([library(all_loader),tools(loader),ports(loader),wrapper(loader),lgtunit(coverage_report),lgtunit(tap_output),lgtunit(tap_report),lgtunit(xunit_output),lgtunit(xunit_report),contributions(loader)]),lgtdoc::all([xml_docs_directory('$cwd/../docs'),omit_path_prefixes(['$LOGTALKUSER/','$LOGTALKHOME/'])]),halt."
+goal="set_logtalk_flag(source_data,on),logtalk_load([library(all_loader),tools(loader),ports(loader),wrapper(loader),lgtunit(coverage_report),lgtunit(tap_output),lgtunit(tap_report),lgtunit(xunit_output),lgtunit(xunit_report),contributions(loader)]),lgtdoc::all([xml_docs_directory('$cwd/../docs/sources'),omit_path_prefixes(['$LOGTALKUSER/','$LOGTALKHOME/'])]),halt."
 
 
 print_version() {
@@ -67,7 +67,7 @@ usage_help()
 	echo "  $(basename "$0") -h"
 	echo
 	echo "Optional arguments:"
-	echo "  -p back-end Prolog compiler (default is $backend)"
+	echo "  -p backend Prolog compiler (default is $backend)"
 	echo "     (possible values are b, cx, eclipse, gnu, ji, lean, qp, sicstus, swi, xsb, xsbmt, and yap)"
 	echo "  -v print version of $(basename "$0")"
 	echo "  -h help"
@@ -123,20 +123,26 @@ elif [ "$p_arg" == "yap" ] ; then
 	prolog='YAP'
 	logtalk="yaplgt$extension -g"
 elif [ "$p_arg" != "" ] ; then
-	echo "Error! Unsupported back-end Prolog compiler: $p_arg" >&2
+	echo "Error! Unsupported backend Prolog compiler: $p_arg" >&2
 	usage_help
 	exit 1
 elif [ ! "$(command -v $backend)" ] ; then
-	echo "Error! Default back-end Prolog compiler not found: $prolog" >&2
+	echo "Error! Default backend Prolog compiler not found: $prolog" >&2
 	usage_help
 	exit 1
 fi
 
 $logtalk "$goal"
-cd "$cwd/../docs" || exit 1
-lgt2html
-rm ./*.xml
-rm ./*.dtd
-rm ./*.xsd
+cd "$cwd/../docs/sources" || exit 1
+lgt2rst -t "Logtalk APIs"
+mv _conf.py conf.py
+make clean
+make html
+make linkcheck
+cp -R _build/html/* ../
+make clean
+mv conf.py _conf.py
+rm *.xml
+rm *.rst
 
 exit 0
